@@ -12,7 +12,7 @@ composition.
 
 """
 from thermosteam import Stream
-from biorefineries import lipidcane as lc
+from biosteam import main_flowsheet as f
 from numpy import array
 
 __all__ = ('set_lipid_fraction',
@@ -20,7 +20,7 @@ __all__ = ('set_lipid_fraction',
 
 def set_lipid_fraction(lipid_fraction, stream=None, data={}):
     """Adjust composition of lipid cane to achieve desired oil fraction (dry weight)."""
-    if not stream: stream = lc.lipidcane
+    if not stream: stream = f.stream.lipidcane
     if not data:
         carbs_IDs = ('Glucose', 'Sucrose')
         fiber_IDs = ('Lignin', 'Cellulose', 'Hemicellulose')
@@ -70,7 +70,7 @@ def set_lipid_fraction(lipid_fraction, stream=None, data={}):
         raise ValueError(f'lipid cane oil composition of {z_mass_lipid*100:.0f}% dry weight is infeasible')
 
 def get_lipid_fraction(stream=None):
-    if not stream: stream = lc.lipidcane
+    if not stream: stream = f.stream.lipidcane
     imass = stream.imass
     F_dry_mass = stream.F_mass - imass['Water']
     return imass['Lipid'] / F_dry_mass
\ No newline at end of file
